==> labtest-0.2.4.tar.gz: labtest-0.2.4/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup

with open('requirements/prod.txt') as req_file:
    requirements = [x for x in req_file.readlines() if x and x[0] not in ('-', '#')]

with open('requirements/test.txt') as req_file:
    test_requirements = [x for x in req_file.readlines() if x and x[0] not in ('-', '#')]

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()


test_requirements = [
    # TODO: put package test requirements here
]

setup(
    name='labtest',
    version='0.2.4',
    description="Build an isolated test lab for running software in containers.",
    long_description=readme + '\n\n' + history,
    author="Corey Oordt",
    author_email='coreyoordt@gmail.com',
    url='https://github.com/CityOfBoston/labtest',
    packages=[
        'labtest',
    ],
    package_dir={'labtest':
                 'labtest'},
    entry_points={
        'console_scripts': [
            'labtest=labtest.cli:main'
        ]
    },
    include_package_data=True,
    install_requires=requirements,
    license="BSD license",
    zip_safe=False,
    keywords='labtest',
    python_requires='==2.7.*',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Environment :: Console',
        'Topic :: Software Development :: Testing',
        'Topic :: Utilities',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
    ],
    test_suite='tests',
    tests_require=test_requirements
)

==> labtest-0.3.0.tar.gz: labtest-0.3.0/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup

with open('requirements/prod.txt') as req_file:
    requirements = [x for x in req_file.readlines() if x and x[0] not in ('-', '#')]

with open('requirements/test.txt') as req_file:
    test_requirements = [x for x in req_file.readlines() if x and x[0] not in ('-', '#')]

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('CHANGELOG.md') as history_file:
    history = history_file.read()


test_requirements = [
    # TODO: put package test requirements here
]

setup(
    name='labtest',
    version='0.3.0',
    description="Build an isolated test lab for running software in containers.",
    long_description=readme + '\n\n' + history,
    author="Corey Oordt",
    author_email='coreyoordt@gmail.com',
    url='https://github.com/CityOfBoston/labtest',
    packages=[
        'labtest',
    ],
    package_dir={'labtest':
                 'labtest'},
    entry_points={
        'console_scripts': [
            'labtest=labtest.cli:main'
        ]
    },
    include_package_data=True,
    install_requires=requirements,
    license="BSD license",
    zip_safe=False,
    keywords='labtest',
    python_requires='==2.7.*',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Environment :: Console',
        'Topic :: Software Development :: Testing',
        'Topic :: Utilities',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
    ],
    test_suite='tests',
    tests_require=test_requirements
)
